{% extends "django_spire/page/center_card_page.html" %}

{% load static %}

{% block base_title %}
    Login
{% endblock %}

{% block page_center_card_content %}
    {% include 'django_spire/notification/../../../../../core/templates/spire/messages/notification.html' %}

    {% if form_description %}
        {% include 'django_spire/note/info_note.html' with note_type='Note' note_text=form_description %}
    {% endif %}

    <form method="post">
         {% csrf_token %}
        {{ form }}
        <button type="submit" class="w-100 btn btn-app-primary mt-2">Submit</button>
    </form>

    <a class="text-center text-decoration-none" href={% url 'user_account:authentication:mfa:redirect:notification' %}?resend=True>Resend Code?</a>
{% endblock %}
