from django.apps import AppConfig


class DjangoSpireSessionConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    label = 'django_spire_contrib_session'
    name = 'django_spire.contrib.session'
