# Generated by Django 5.2.1 on 2025-05-23 16:00

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_spire_notification', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='PushNotification',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.BooleanField(default=True, editable=False)),
                ('is_deleted', models.BooleanField(default=False, editable=False)),
                ('created_datetime', models.DateTimeField(default=django.utils.timezone.localtime, editable=False)),
            ],
            options={
                'verbose_name': 'Push Notification',
                'verbose_name_plural': 'Push Notifications',
                'db_table': 'django_spire_notification_push',
            },
        ),
    ]
