{% extends 'django_spire/page/full_page.html' %}

{% block full_page_content %}
    <div class="row">
        <div class="col-12">
            {% include 'django_spire/knowledge/entry/container/import_form_container.html' %}
        </div>
    </div>
{% endblock %}
