[data-theme="dark"] {
    --app-primary: #c4a7e7;
    --app-primary-soft: #26233a;
    --app-primary-dark: #907aa9;

    --app-secondary: #908caa;
    --app-secondary-soft: #26233a;
    --app-secondary-dark: #6e6a86;

    --app-accent: #eb6f92;
    --app-accent-soft: #26233a;
    --app-accent-dark: #b4637a;

    --app-success: #31748f;
    --app-success-soft: #26233a;
    --app-success-dark: #286983;

    --app-warning: #f6c177;
    --app-warning-soft: #26233a;
    --app-warning-dark: #ea9d34;

    --app-danger: #eb6f92;
    --app-danger-soft: #26233a;
    --app-danger-dark: #b4637a;

    --app-layer-one: #1f1d2e;
    --app-layer-two: #26233a;
    --app-layer-three: #403d52;
    --app-layer-four: #6e6a86;

    --app-alt-layer-one: #191724;
    --app-alt-layer-two: #21202e;
    --app-alt-layer-three: #393748;
    --app-alt-layer-four: #524f67;

    --app-default-attribute-title-color: #e0def4;
    --app-default-button-text-color: #191724;
    --app-default-text-color: #e0def4;
    --app-default-alt-text-color: #c4c1d4;
    --app-default-link-color: #c4a7e7;
    --app-default-link-hover-color: #eb6f92;

    --app-side-navigation-bg-color: #1f1d2e;
    --app-side-navigation-text-color: #e0def4;
    --app-side-navigation-link-color: #e0def4;
    --app-side-navigation-link-hover-color: #c4a7e7;
    --app-side-navigation-width: 200px;

    --app-mobile-navigation-width: 200px;

    --app-top-navigation-bg-color: #1f1d2e;
    --app-top-navigation-text-color: #e0def4;
    --app-top-navigation-link-color: #c4a7e7;
    --app-top-navigation-link-hover-color: #eb6f92;
    --app-top-navigation-height: 100px;

    --app-footer-bg-color: #1f1d2e;
    --app-footer-text-color: #e0def4;
    --app-footer-link-color: #c4a7e7;
    --app-footer-link-hover-color: #eb6f92;

    --app-table-row-color: #191724;
    --app-table-row-alt-color: #26233a;
    --app-table-row-hover-color: #403d52;

    --bs-border-color: #403d52;

    --app-shadow-light: rgba(0, 0, 0, 0.2);
    --app-shadow-medium: rgba(0, 0, 0, 0.4);
    --app-shadow-heavy: rgba(0, 0, 0, 0.6);
    --app-shadow-navigation: rgba(0, 0, 0, 0.8);

    --app-border-translucent-light: rgba(64, 61, 82, 0.175);
    --app-focus-ring-primary: rgba(196, 167, 231, 0.25);
}
